@@ -47,14 +47,14 @@ def parse_collection_query(request,
     return collection, query
 
 
-async def parse_collection_document_query(request, allow_include=False):
+async def parse_collection_document_query(request):
     """Gets the resource collection, the data member from the document, and
     query parameters from the request.
     """
 
     parse_headers(request)
     collection = parse_collection(request)
-    query = collection.parse_query(request, allow_include=allow_include)
+    query = collection.parse_query(request)
     document = await collection.parse_document(request)
     return collection, document, query
 
@@ -95,13 +95,12 @@ async def parse_relationship_query(request,
     return relationship, query
 
 
-async def parse_relationship_document_query(request, allow_include=False):
+async def parse_relationship_document_query(request):
     """Gets the relationship and query parameters from the request."""
 
     parse_headers(request)
     relationship = parse_relationship(request)
-    query = relationship.collection.parse_query(request,
-                                                allow_include=allow_include)
+    query = relationship.collection.parse_query(request)
     document = await relationship.parse_document(request)
     return relationship, document, query
 
