@@ -78,8 +78,7 @@ class Table:
         collection_name = pascal_to_snake(cls.__name__)
         cls.collection = Collection(collection_name, cls)
         Collection.by_name[collection_name] = cls.collection
-        cls.attributes = []
-        cls.attribute_names = []
+        cls.attributes_by_name = {}
         cls.relationships = []
         cls.local_relationships = []
         cls.remote_relationships = []
@@ -109,8 +108,7 @@ class Table:
             if isinstance(col, Attribute):
                 col.name = name
                 cls.columns.append(col)
-                cls.attributes.append(col)
-                cls.attribute_names.append(col.name)
+                cls.attributes_by_name[col.name] = col
             elif isinstance(col, Relationship):
                 col.name = name
                 cls.relationships.append(col)
@@ -177,14 +175,15 @@ class Table:
                                       if col in columns_now)))
         # pylint: disable=no-member
         if hasattr(cls, 'id') and cls.id.type_ == Int64:
-            stmt_table = (f'CREATE SEQUENCE IF NOT EXISTS seq_{cls.name};\n'
-                          f'CREATE TABLE IF NOT EXISTS {cls.name} (\n   '
-                          f'{table_fields}\n);')
+            stmt_table = (
+                f'CREATE SEQUENCE IF NOT EXISTS data.seq_{cls.name};\n'
+                f'CREATE TABLE IF NOT EXISTS data.{cls.name} (\n   '
+                f'{table_fields}\n);')
         else:
-            stmt_table = (f'CREATE TABLE IF NOT EXISTS {cls.name} (\n   '
+            stmt_table = (f'CREATE TABLE IF NOT EXISTS data.{cls.name} (\n   '
                           f'{table_fields}\n);')
         stmts_fk = [
-            f'ALTER TABLE {cls.name} ADD {constraint}'
+            f'ALTER TABLE data.{cls.name} ADD {constraint}'
             for col in cls.constraints if col in columns_later
             for constraint in col.sql_constraints()
         ]
@@ -250,7 +249,10 @@ async def create_all(pool):
         pool: Connection pool to the database in which to create the SQL tables.
     """
 
-    await db_execute(pool, 'CREATE EXTENSION IF NOT EXISTS "uuid-ossp";')
+    await db_execute(pool, 'CREATE SCHEMA data;')
+    await db_execute(
+        pool, 'CREATE EXTENSION IF NOT EXISTS "uuid-ossp"'
+        ' WITH SCHEMA data;')
 
     # pylint: disable=protected-access
     stmts_delayed = []  # Delayed foreign key constraints
