@@ -28,8 +28,6 @@ from json import dumps, loads
 class Type:
     """Abstract base class for supported database types."""
 
-    # pylint: disable=too-few-public-methods
-
     @staticmethod
     def from_json(value):
         """Converts a JSON value to the corresponding Python value."""
@@ -59,8 +57,6 @@ class Type:
 class Bool(Type):
     """Type for booleans."""
 
-    # pylint: disable=too-few-public-methods
-
     name = 'BOOLEAN'
 
 
@@ -71,13 +67,11 @@ Boolean = Bool
 class DateTime(Type):
     """Type for date times."""
 
-    # pylint: disable=too-few-public-methods
-
     name = 'TIMESTAMP'
 
     @staticmethod
     def sql(value):
-        return f'"{value.isoformat()}"'
+        return f"'{value.isoformat()}'"
 
     @staticmethod
     def from_json(value):
@@ -91,13 +85,11 @@ class DateTime(Type):
 class DateTimeTZ(Type):
     """Type for date times with time zone information."""
 
-    # pylint: disable=too-few-public-methods
-
     name = 'TIMESTAMP WITH TIME ZONE'
 
     @staticmethod
     def sql(value):
-        return f'"{value.isoformat()}"'
+        return f"'{value.isoformat()}'"
 
     @staticmethod
     def from_json(value):
@@ -115,40 +107,30 @@ DateTimeTimeZone = DateTimeTZ
 class Float32(Type):
     """Type for 32 bit floating point numbers."""
 
-    # pylint: disable=too-few-public-methods
-
     name = 'FLOAT'
 
 
 class Float64(Type):
     """Type for 64 bit floating point numbers."""
 
-    # pylint: disable=too-few-public-methods
-
     name = 'DOUBLE PRECISION'
 
 
 class Int16(Type):
     """Type for 16 bit signed integers."""
 
-    # pylint: disable=too-few-public-methods
-
     name = 'SMALLINT'
 
 
 class Int32(Type):
     """Type for 32 bit signed integers."""
 
-    # pylint: disable=too-few-public-methods
-
     name = 'INT'
 
 
 class Int64(Type):
     """Type for 64 bit signed integers."""
 
-    # pylint: disable=too-few-public-methods
-
     name = 'BIGINT'
 
 
@@ -173,8 +155,6 @@ class Json(Type):
 class Numeric(Type):
     """Type for arbitrary precision numbers."""
 
-    # pylint: disable=too-few-public-methods
-
     name = 'NUMERIC'
 
     @staticmethod
@@ -184,8 +164,6 @@ class Numeric(Type):
         class NumericWith(Type):
             """Type for SQL NUMERIC(precision, scale) types."""
 
-            # pylint: disable=too-few-public-methods
-
             name = f'NUMERIC({precision}, {scale})' if scale is not None else \
                     f'NUMERIC({precision})'
 
@@ -195,8 +173,6 @@ class Numeric(Type):
 class String(Type):
     """Type for strings."""
 
-    # pylint: disable=too-few-public-methods
-
     name = 'TEXT'
 
     @staticmethod
@@ -211,8 +187,6 @@ class String(Type):
         class StringWith(Type):
             """Type for SQL VARCHAR(max_length) types."""
 
-            # pylint: disable=too-few-public-methods
-
             name = f'VARCHAR({max_length})'
 
             @staticmethod
@@ -226,6 +200,4 @@ class String(Type):
 class Uuid(Type):
     """Type for uuids."""
 
-    # pylint: disable=too-few-public-methods
-
     name = 'UUID'
