@@ -54,7 +54,12 @@ from ajsonapi.postgres import (
     convert_unique_violation_error,
     convert_violation_error,
 )
-from ajsonapi.query import parse_fields, parse_page, query_has_parameter
+from ajsonapi.query import (
+    parse_fields,
+    parse_page,
+    query_has_parameter,
+    subquery,
+)
 from ajsonapi.responses import document_response, no_content_response
 from ajsonapi.uri.resource import Resource
 
@@ -558,7 +563,8 @@ class GetCollectionEnvironment:
             return
         for relationship, remote_includes in includes.items():
             remote_collection = relationship.rtable.collection
-            remote_ids = relationship.collection_remote_ids(self.query, ids)
+            remote_ids = relationship.collection_remote_ids(
+                subquery(self.query, relationship), ids)
             self.included_environments.append(
                 GetCollectionIncludedEnvironment(remote_collection, remote_ids,
                                                  self))
